// importing the properties from d3
import {
  select,
  csv,
  scaleLinear,
  scaleTime,
  extent,
  max,
  axisLeft,
  axisBottom,
  area,
  curveBasis,
  format
} from 'd3';

const svg = select('svg');

// Add width and height of the chart
const width = +svg.attr('width');
const height = +svg.attr('height');
// display the specified HTML code inside the specified HTML element.
const render = data => {
  const title = 'Death Rate in India (2000-2012)';
 // labeling the attributes to the chart  
  const xValue = d => d.Year;
  const xAxisLabel = 'Year';
  
  const yValue = d => d.Death;
  const circleRadius = 5;
  const yAxisLabel = 'Death Rate';
  
  const margin = { top: 60, right: 40, bottom: 88, left: 105 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  // Add scaleTime function to automatically adjust years
  const xScale = scaleTime()
    .domain(extent(data, xValue))
    .range([0, innerWidth])
    .nice();
  
  // Add scaleLinear function to automatically adjust population
  const yScale = scaleLinear()
    .domain([0, max(data, yValue)])
    .range([innerHeight, 0])
    .nice();
  
  // Locate the graph
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);
  
  // Add attributes of x-axis
  const xAxis = axisBottom(xScale)
    .ticks(6)
    .tickSize(-innerHeight)
    .tickPadding(15);

  // Format y-axis tick
  const yAxisTickFormat = number =>
    format('.1s')(number)
      .replace('G', 'B');
  
    // Add attributes of y-axis
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(10)
    .tickFormat(yAxisTickFormat);
  
  const yAxisG = g.append('g').call(yAxis);
  yAxisG.selectAll('.domain').remove();
  
  // Add attributes of y-axis
  yAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', -60)
      .attr('x', -innerHeight / 2)
      .attr('fill', 'black')
      .attr('transform', `rotate(-90)`)
      .attr('text-anchor', 'middle')
      .text(yAxisLabel);
  
  const xAxisG = g.append('g').call(xAxis)
    .attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  // Add attributes of x-axis
  xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 80)
      .attr('x', innerWidth / 2)
      .attr('fill', 'black')
      .text(xAxisLabel);
  
  // Control the area
  const areaGenerator = area()
    .x(d => xScale(xValue(d)))
    .y0(innerHeight)
    .y1(d => yScale(yValue(d)))
    .curve(curveBasis);
  
  // Add additributes to path
  g.append('path')
      .attr('class', 'line-path')
      .attr('d', areaGenerator(data));
  
  // Control title
  svg.append('text')
      .attr('class', 'title')
      .attr('x', width / 2)
      .attr('y', 45)
      .text(title);
};
// git hub url for my data set 
csv('https://gist.githubusercontent.com/aashrithd4/2888efda3cc427e29e5d232d61b79e08/raw/1682115b4ed57779f8f904cf2edaaa3ce62e5b5d/Death.csv')
  .then(data => {
    data.forEach(d => {
      d.Death = +d.Death;
      d.Year = new Date(d.Year);
    });
    render(data);
  });